#!/bin/bash

# Определение типа пользователя, под кем запускается установка
case "`uname`" in
	Darwin*)
	case "`id -un`" in
		root)
		;;
		*)
		echo Sorry, you must have administrative priviledges to install this software.
		exit 1
		;;
	esac
	;;
	*)
	case "`id`" in
		uid=0*)
		;;
		*)
		echo Sorry, you must be root to install this software.
		exit 1
		;;
	esac
	;;
esac

lowercase(){
    echo "$1" | sed "y/ABCDEFGHIJKLMNOPQRSTUVWXYZ/abcdefghijklmnopqrstuvwxyz/"
}
#####################################
# HARDWARE
#####################################
OS=`lowercase \`uname\``
ARCH=`uname -m`
KERNEL=`uname -r`

echo
echo HARDWARE TEST
echo ===========================
echo OS Type: $OS
echo Architecture: $ARCH
echo Kernel: $KERNEL
echo ===========================
echo

PKG_NAME="Katusha Printer/MFP Universal Driver"
LAST="2.0.1-24262-rebuild"

PATH=/usr/xpg4/bin:/bin:/usr/bin:/usr/ucb:${PATH}
WORKDIR=$(cd "$(dirname "$0")"; pwd)

PACKAGES="$WORKDIR/packages"
PACKAGE_KUMD=katusha-mfp-driver-universal-amd64

RUN_KATUSHA_M247=to-install-katusha-M247-drivers
RUN_KATUSHA_M348=to-install-katusha-M348-drivers

VERSION_FILES="file://$WORKDIR/docs"

# Reset umask for install package...
umask 002
# Determine correct echo options...
if (echo "testing\c"; echo 1,2,3) | grep c >/dev/null; then
	ac_n=-n
	ac_c=
else
	ac_n=
	ac_c='\c'
fi

# установка прав на папку CUPS interfaces
if [ ! -d /etc/cups/interfaces ]; then
	mkdir -p /etc/cups/interfaces
	chmod 755 /etc/cups/interfaces
	chown root:lp /etc/cups/interfaces
fi
if [ ! -d /var/spool/lpd ]; then
	mkdir -p /var/spool/lpd
	chmod 755 /var/spool/lpd
	chown lp:lp /var/spool/lpd
fi
echo "Setup CUPS interfaces access ==> [OK]"

# Checking CUPS already Installed
if test ! -r /usr/lib/cups -a ! -h /usr/lib/cups; then
	echo Sorry, you must first install \'/usr/lib/cups\'!
	exit 1
fi
echo "Checking CUPS support ==> [OK]"

if test -f /usr/.writetest; then
	rm -f /usr/.writetest
fi
echo "Testing /usr/ write file operations ==> [OK]"

title="(notice) выберите из списка пакет, который хотите установить:
(warning) чтобы установить другой пакет, перезапустите установщик Katusha еще раз!"
prompt="(action) выберите требуемое действие:"
options=("Install Important Packages" #1
				 "katusha MFP Driver Universal [with Models.html]" #2
				 "Katusha MFP Driver for M247 Series" #3
				 "Katusha MFP Driver for M348 Series" #4
         )
echo
echo +++++++++++++++++++++++++++++++++++++++++++
echo Build Date: 19.09.2024\ / Katusha
echo Type: All-in-One Driver Package
echo Name: Katusha UNIX Printer/Scanner DriverPack Utility
echo Version: 2.0-1-untested
echo Support: M Series, P Series, All Devices
echo +++++++++++++++++++++++++++++++++++++
echo
echo "$title"
PS3="$prompt "
COLUMNS=12
select opt in "${options[@]}" "Отменить"; do
    case "$REPLY" in
    1) echo "Вы выбрали $opt, ожидайте завершения установки";
		# Определение необходимости установки пакетов
		which wget
		if [[ $(echo $?) == "0" ]]; then
			echo "[wget] are installed!"
			wget -q --tries=10 --timeout=20 --spider http://google.com
			if [[ $? -eq 0 ]]; then
					echo "We are Online!"
					if [[ $(cat /etc/os-release | egrep -c "Astra|SparkyLinux") -ge 1 ]]; then
						. /etc/os-release
						OS=$NAME
						VER=$VERSION_ID
						echo
						echo Your OS: $OS
						echo Version: $VER
						echo
						sudo apt update
						echo Сhecking dependencies required to run the installation script...
						NEED_PACKAGES="lynx sane libcupsimage2" # simple-scan
						for PKG in $NEED_PACKAGES
						do
							if [ $(dpkg-query -W -f='${Status}' $PKG 2>/dev/null | grep -c "ok installed") -eq 0 ];
								then
									echo Installing necessary packages...
									sudo apt-get -y install $PKG;
							fi
						done
						echo "Updating DONE"
					fi
					if [[ $(cat /etc/os-release | grep -c "RED OS") -ge 1 ]]; then
						. /etc/os-release
						OS=$NAME
						VER=$VERSION_ID
						echo
						echo Your OS: $OS
						echo Version: $VER
						echo
						sudo dnf makecache
						sudo dnf install lynx
						echo "Updating DONE"
					fi
					#Next Statements
			else
				echo "Please check your internet connection!"
			fi
		else
			echo "[wget] are not installed!"
			echo "please install [wget] manual or check your internet connection"
		fi
    break;;
		2) echo "Вы выбрали установку [$opt]";
		if [[ $(cat /etc/os-release | egrep -c "Astra|SparkyLinux") -ge 1 ]]; then
			# Confirming install procedure...
			if test "$*" = "now"; then
			  echo Лицензия на программное обеспечение автоматически принимается с помощью опции командной строки
			else
			  echo
			  echo "This script will install the [$PKG_NAME] software version: [$LAST] on your system."
			  while true ; do
			    echo $ac_n "Do you wish to continue? type: Yes (y) or No (n): $ac_c"
			    read yesno
			    case "$yesno" in
			      y | yes | Y | Yes | YES)
			      break
			      ;;
			      n | no | N | No | NO)
			      echo ----------------------
			      echo Installation cancelled
			      exit 1
			      ;;
			      *)
			      echo ----------------------
			      echo Please enter Yes or No.
			      ;;
			    esac
			  done
			  echo
			  echo ------------------------------------------------------------------
			  lynx -dump $VERSION_FILES/KUMD/Version.html
			  echo ------------------------------------------------------------------
			  echo
			  while true ; do
			    echo $ac_n "Do you understand and agree? type: Yes (y) or No (n): $ac_c"
			    read yesno
			    case "$yesno" in
			      y | yes | Y | Yes | YES)
			      break
			      ;;
			      n | no | N | No | NO)
			      echo ----------------------
			      echo Installation cancelled
			      exit 1
			      ;;
			      *)
			      echo ----------------------
			      echo Please enter Yes or No.
			      ;;
			    esac
			  done
			fi
			. /etc/os-release
			OS=$NAME
			VER=$VERSION_ID
			echo
			echo Your OS: $OS
			echo Version: $VER
			echo
			sudo dpkg -i "$PACKAGES/$PACKAGE_KUMD.deb"
		fi
		if [ $(cat /etc/os-release | grep -c "RED OS") -ge 1 ] ; then
			echo `uname -a`
			# Confirming install procedure...
			if test "$*" = "now"; then
				echo Лицензия на программное обеспечение автоматически принимается с помощью опции командной строки
			else
				echo
				echo "This script will install the [$PKG_NAME] software version: [$LAST] on your system."
				while true ; do
					echo $ac_n "Do you wish to continue? type: Yes (y) or No (n): $ac_c"
					read yesno
					case "$yesno" in
						y | yes | Y | Yes | YES)
						break
						;;
						n | no | N | No | NO)
						echo ----------------------
						echo Installation cancelled
						exit 1
						;;
						*)
						echo ----------------------
						echo Please enter Yes or No.
						;;
					esac
				done
				echo
				echo ------------------------------------------------------------------
				lynx -dump $VERSION_FILES/KUMD/Version.html
				echo ------------------------------------------------------------------
				echo
				while true ; do
					echo $ac_n "Do you understand and agree? type: Yes (y) or No (n): $ac_c"
					read yesno
					case "$yesno" in
						y | yes | Y | Yes | YES)
						break
						;;
						n | no | N | No | NO)
						echo ----------------------
						echo Installation cancelled
						exit 1
						;;
						*)
						echo ----------------------
						echo Please enter Yes or No.
						;;
					esac
				done
			fi
			. /etc/os-release
			OS=$NAME
			VER=$VERSION_ID
			echo
			echo Your OS: $OS
			echo Version: $VER
			echo
			sudo rpm -Uvh "$PACKAGES/$PACKAGE_KUMD.rpm"
		fi
		#Next Statements
		break;;
		3) echo && echo "=== $opt ===";
		sudo bash $RUN_KATUSHA_M247.task
		break;;
		4) echo && echo "=== $opt ===";
		sudo bash $RUN_KATUSHA_M348.task
		break;;
    $((${#options[@]}+1))) echo "Установка была отменена";
		break;;
    *) echo "Неправильный ввод. Вы ошиблись. Повторите.";continue;;
    esac
done
